==> tuia-explore-center-api-0.0.1-20190530.115859-41-sources.jar: cn/tuia/explore/center/api/dto/rsp/MessageDto.java <==
package cn.tuia.explore.center.api.dto.rsp;

import java.io.Serializable;
import java.util.Date;

/**
 * @author ElinZhou zhoufeng@duiba.com.cn
 * @version $Id: MessageDto.java , v 0.1 2019-05-29 09:48 ElinZhou Exp $
 */
public class MessageDto implements Serializable {

    private static final long serialVersionUID = -3105406969336267802L;
    private long msgId;

    private String title;

    private String content;

    private String icon;

    private Date time;

    private String jumpUrl;

    private boolean readed;

    private Long userId;

    public MessageDto(String title, String content, String icon, String jumpUrl, Long userId) {
        this.title = title;
        this.content = content;
        this.icon = icon;
        this.jumpUrl = jumpUrl;
        this.userId = userId;
    }

    public long getMsgId() {
        return msgId;
    }

    public void setMsgId(long msgId) {
        this.msgId = msgId;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getIcon() {
        return icon;
    }

    public void setIcon(String icon) {
        this.icon = icon;
    }

    public Date getTime() {
        return time;
    }

    public void setTime(Date time) {
        this.time = time;
    }

    public String getJumpUrl() {
        return jumpUrl;
    }

    public void setJumpUrl(String jumpUrl) {
        this.jumpUrl = jumpUrl;
    }

    public boolean isReaded() {
        return readed;
    }

    public void setReaded(boolean readed) {
        this.readed = readed;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }
}

==> tuia-explore-center-api-0.0.1-20190602.055516-53-sources.jar: cn/tuia/explore/center/api/dto/rsp/MessageDto.java <==
package cn.tuia.explore.center.api.dto.rsp;

import java.io.Serializable;
import java.util.Date;

/**
 * @author ElinZhou zhoufeng@duiba.com.cn
 * @version $Id: MessageDto.java , v 0.1 2019-05-29 09:48 ElinZhou Exp $
 */
public class MessageDto implements Serializable {

    private static final long serialVersionUID = -3105406969336267802L;
    private long msgId;

    private String title;

    private String content;

    private String icon;

    private Date time;

    private String jumpUrl;

    private boolean readed;

    private Long userId;

    private Integer msgType;

    public MessageDto(String title, String content, String icon, String jumpUrl, Long userId) {
        this.title = title;
        this.content = content;
        this.icon = icon;
        this.jumpUrl = jumpUrl;
        this.userId = userId;
    }

    public long getMsgId() {
        return msgId;
    }

    public void setMsgId(long msgId) {
        this.msgId = msgId;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getIcon() {
        return icon;
    }

    public void setIcon(String icon) {
        this.icon = icon;
    }

    public Date getTime() {
        return time;
    }

    public void setTime(Date time) {
        this.time = time;
    }

    public String getJumpUrl() {
        return jumpUrl;
    }

    public void setJumpUrl(String jumpUrl) {
        this.jumpUrl = jumpUrl;
    }

    public boolean isReaded() {
        return readed;
    }

    public void setReaded(boolean readed) {
        this.readed = readed;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Integer getMsgType() {
        return msgType;
    }

    public void setMsgType(Integer msgType) {
        this.msgType = msgType;
    }
}
